#ifndef NT2_INCLUDE_CONSTANTS_FACT_5_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_FACT_5_HPP_INCLUDED

#include <nt2/constant/include/constants/fact_5.hpp>

#endif
